Get the daily puzzle input from a cache file, if it exists, otherwise GET it from the
AoC website and cache it to a file – to avoid making unnecessary requests. Stores
cache files in:
Get the puzzle input for the given year and day (eg 2024, 1)Run the function that solves the given part of the puzzle (ie 1 or 2)Return the puzzle results using the given method:Solve: Print the puzzle solutionSubmit: Submit the puzzle solution to adventofcode.com and print a message
indicating whether or not the solution was correct